/* this is part of the libspopc library sources
 * copyright  2002 Benoit Rouits <brouits@free.fr>
 * released under the terms of GNU LGPL
 * (GNU Lesser General Public Licence).
 * libspopc offers simple API for a pop3 client (MTA).
 * See RFC 1725 for pop3 specifications.
 * more information on http://brouits.free.fr/libspopc/
 */

/*********************************************************
 * this example show what MUST NOT BE DONE with libspopc *
 *********************************************************/

#include <string.h> /* use of strcpy() */
#include <stdio.h> /* use of printf() */
#include <stdlib.h> /* use of exit() */
#include <sys/types.h>
#include <sys/socket.h>
#include <netdb.h>
#include <netinet/in.h>

/* #include <libspopc.h> */
#include "session.c"
#include "parsing.c"
#include "queries.c"
#include "format.c"

int main(int argc,char** argv){

	int mysock;
	char myservername[64];
	char username[64];
	char password[64];

	struct hostent myserver;
	struct sockaddr_in myconnection;

	char* srvdata=NULL;
	char* mymessage=NULL;
	int* mylist;
	char** myuidl;
	int i=0,last;

	if(argc<4){
		printf("Usage: %s servername username password\n",argv[0]);
		exit(0);
	}
	strcpy(myservername,argv[1]);
	strcpy(username,argv[2]);
	strcpy(password,argv[3]);

	mysock=pop3_prepare(myservername,0,&myconnection,&myserver);
	if(-1==mysock){
		printf("check your network...\n");
		exit(1);
	}
	srvdata=pop3_connect(mysock,&myconnection);
	free(srvdata);
	srvdata=pop3_user(mysock,username);
	free(srvdata);
	srvdata=pop3_pass(mysock,password);
	free(srvdata);
	printf("\n---\nTEST STAT\n\n");
	srvdata=pop3_stat(mysock);
	last=stat2last(srvdata);
	printf("stat: %d mail(s)\n",stat2last(srvdata));
	printf("stat: %d bytes\n",stat2bytes(srvdata));
	free(srvdata);
	printf("\n---\nBAD USE OF LIST\n\n");
	printf("After using pop3_list(mysock,x) with x != 0\n");
	printf("It is DISADVSED to use list2array() since\n");
	printf("the list is of one element, however, it doesn't\n");
	printf("crash... For example, the list can be like that :\n");
	srvdata=pop3_list(mysock,last);
	mylist=list2array(srvdata);/* you should better use listi2size() ! */
	printf("list:\n");
	for(i=1;i<=(mylist?mylist[0]:0);i++){
		printf(" %d: %d bytes\n",i,mylist?mylist[i]:0);
	}
	i--;
	free(mylist);mylist=NULL;
	printf("The good way to retrieve a message size after a\n");
	printf("pop3_list(mysock,x) with x!=0 is to use function\n");
	printf("int listi2size(response); hence, the result is an 'int'\n");
	printf("size of msg %d is %d bytes\n",last,listi2size(srvdata));
	free(srvdata);
	printf("\n---\nBAD USE OF UIDL\n\n");
	printf("uidl can be called the same way as list:\n");
	printf("it is possible to call pop3_uidl(mysock,x)\n");
	printf("with x != 0. Hence response is a single signature\n");
	printf("for message 'x'. It is DISADVISED to use uidl2array()\n");
	printf("since you only have a single uid signature. However, the\n");
	printf("result will be the same kind as list2array but\n");
	printf("you must test if array[i]!=NULL ...\n");
	srvdata=pop3_uidl(mysock,last);
	myuidl=uidl2array(srvdata);
	printf("uidl: %s signatures\n",myuidl?myuidl[0]:"0");
	for(i=1;i<=(myuidl?atoi(myuidl[0]):0);i++){
		printf(" %d: %s\n",i,myuidl?myuidl[i]:0);
	}
	last=atoi(myuidl[0]);
	for(i=0;i<=last;i++){
		free(myuidl[i]);
	}
	free(myuidl);
	printf("The good way to retrieve a single signature is to use\n");
	printf("char* uidli2sig(resp); after a call to pop3_uidl(mysock,x)\n");
	printf("if x != 0 :\n");
	mymessage=uidli2sig(srvdata);
	printf("message %d has signature: %s\n",last,mymessage);
	free(srvdata);
	free(mymessage);
	pop3_quit(mysock);
	pop3_disconnect(mysock);
	exit(0);
}

